@@ -1,9 +1,20 @@
 # %%
-import os
+# import os
 # os.chdir(os.path.dirname(os.path.abspath('examples.py')))
-import findpeaks
-print(dir(findpeaks))
-print(findpeaks.__version__)
+# import findpeaks
+# print(dir(findpeaks))
+# print(findpeaks.__version__)
+
+# %%
+# Load library
+from findpeaks import findpeaks
+# Data
+X = [10,11,9,23,21,11,45,20,11,12]
+# Initialize
+fp = findpeaks(method='peakdetect', lookahead=1)
+results = fp.fit(X)
+# Plot
+fig=fp.plot()
 
 # %%
 from findpeaks import findpeaks
@@ -14,7 +25,7 @@ results = fp.fit(X)
 
 fp.plot_preprocessing()
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 fp.plot_mesh()
 
 
@@ -24,7 +35,7 @@ results = fp.fit(X)
 
 fp.plot()
 fp.plot_preprocessing()
-fp.plot_peristence()
+fp.plot_persistence()
 fp.plot_mesh()
 
 # %%
@@ -41,7 +52,7 @@ for method in methods:
             fp = findpeaks(lookahead=lookahead, interpolate=interpolate, method=method)
             results = fp.fit(X)
             # fp.plot()
-            # fp.plot_peristence()
+            # fp.plot_persistence()
 
 # fp.results['df_interp']
 fp.results['df']
@@ -52,7 +63,7 @@ X = [10,11,9,23,21,11,45,20,11,12]
 fp = findpeaks(lookahead=1, method="topology")
 results = fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 
 # %% Run over all methods and many parameters
@@ -85,7 +96,7 @@ for getfilter in filters:
 #%% Plot each seperately
 fp.plot_preprocessing()
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 fp.plot_mesh()
 
 # Make mesh plot
@@ -100,7 +111,7 @@ fp = findpeaks(method='peakdetect', lookahead=1, interpolate=10, verbose=3)
 X = fp.import_example('1dpeaks')
 fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 
 from findpeaks import findpeaks
@@ -108,14 +119,14 @@ fp = findpeaks(method='topology')
 X = fp.import_example('1dpeaks')
 fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 from findpeaks import findpeaks
 fp = findpeaks(method='topology',  interpolate=10)
 X = fp.import_example('1dpeaks')
 fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 
 from tabulate import tabulate
@@ -135,7 +146,7 @@ img = fp.import_example('2dpeaks')
 fp.fit(img)
 fp.plot(cmap='hot')
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 fp = findpeaks(method='mask')
 img = fp.import_example()
@@ -158,7 +169,7 @@ fp.plot()
 
 fp.plot_preprocessing()
 fp.plot_mesh()
-fp.plot_peristence()
+fp.plot_persistence()
 
 # %%
 from findpeaks import findpeaks
@@ -167,12 +178,12 @@ X = [1,1,1.1,1,0.9,1,1,1.1,1,0.9,1,1.1,1,1,0.9,1,1,1.1,1,1,1,1,1.1,0.9,1,1.1,1,1
 fp = findpeaks(method='peakdetect', lookahead=1, verbose=3)
 results = fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 fp = findpeaks(method='topology')
 results=fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 # %%
 X = [10,11,9,23,21,11,45,20,11,12]
@@ -183,7 +194,7 @@ fp.plot()
 fp = findpeaks(method='topology', lookahead=1, interpolate=10)
 fp.fit(X)
 fp.plot()
-fp.plot_peristence()
+fp.plot_persistence()
 
 # %%
 from math import pi
@@ -202,13 +213,14 @@ fp.plot()
 fp = findpeaks(method='topology')
 results=fp.fit(X)
 
-fp.plot_peristence()
+fp.plot_persistence()
 # fp.results['Xdetect']>1
 
 # %% Denoising example
 from findpeaks import findpeaks
 fp = findpeaks()
 
+
 img = fp.import_example('2dpeaks_image')
 import findpeaks
 
@@ -252,15 +264,6 @@ image_mean = findpeaks.mean_filter(img.copy(), win_size=winsize)
 # median filter
 image_median = findpeaks.median_filter(img.copy(), win_size=winsize)
 
-# %%
-# import cv2
-# imageStarsCropped = cv2.bitwise_and(img, img_fastnl)
-# plt.figure(); plt.imshow(imageStarsCropped, cmap='gray'); plt.grid(False)
-# np.std(img)
-# np.std(imageStarsCropped)
-# np.std(img_fastnl)
-# fp.fit(imageStarsCropped)
-
 # Plotting
 import matplotlib.pyplot as plt
 plt.figure(); plt.imshow(img_fastnl, cmap='gray'); plt.title('Fastnl'); plt.grid(False)
@@ -274,7 +277,9 @@ plt.figure(); plt.imshow(image_median, cmap='gray'); plt.title('Median')
 
 
 from findpeaks import findpeaks
-fp = findpeaks(method='topology', scale=False, denoise=None, togray=False, imsize=False, verbose=3)
-fp.fit(image_lee_enhanced)
-fp.plot_peristence()
-fp.plot_mesh(wireframe=False, title='image_lee_enhanced')
+fp = findpeaks(method='topology', scale=False, denoise='fastnl', togray=True, imsize=False, verbose=3)
+fp.fit(img)
+fp.plot_persistence()
+fp.plot_mesh(wireframe=False, title='image_lee_enhanced', view=(30,30))
+
+# %%
\ No newline at end of file
