@@ -13,8 +13,9 @@ import matplotlib.pyplot as plt
 from tqdm import tqdm
 import pandas as pd
 import numpy as np
-import wget
 import os
+import requests
+from urllib.parse import urlparse
 
 
 class findpeaks():
@@ -480,6 +481,7 @@ class findpeaks():
             ax[iax].grid(False)
             ax[iax].set_title('Input\nRange: [%.3g,%.3g]' %(X.min(), X.max()))
             iax = iax + 1
+            plt.show()
 
         # Resize
         if self.imsize:
@@ -610,6 +612,7 @@ class findpeaks():
         if not self.args['type']=='peaks2d':
             print('[findpeaks] >Requires results of 2D data <return>.')
             return None
+        ax_method, ax_mesh = None, None
         figsize = figsize if figsize is not None else self.args['figsize']
         # Plot preprocessing steps
         self.plot_preprocessing()
@@ -623,6 +626,7 @@ class findpeaks():
 
         # Plot mesh
         ax_mesh = self.plot_mesh(figsize=figsize)
+        
         # Return axis
         return (ax_method, ax_mesh)
 
@@ -689,7 +693,9 @@ class findpeaks():
         ax3.imshow(Xdetect, cmap, interpolation="nearest")
         ax3.set_title(self.method + ' method')
         ax3.grid(False)
-
+        
+        # Show plot
+        plt.show()
         # Return
         return (ax1, ax2, ax3)
 
@@ -731,6 +737,9 @@ class findpeaks():
         if not hasattr(self, 'results'):
             if self.verbose>=3: print('[findpeaks] >Nothing to plot. Hint: run the fit() function.')
             return None
+        if self.results.get('Xproc', None) is None:
+            if self.verbose>=3: print('[findpeaks] >These analysis do not support mesh plotting. This may be caused because your are analysing 1D.')
+            return None
 
         figsize = figsize if figsize is not None else self.args['figsize']
         if self.verbose>=3: print('[findpeaks] >Plotting 3d-mesh..')
@@ -887,9 +896,10 @@ class findpeaks():
         ax2.set_xlim((np.min(X), np.max(X)))
         ax2.set_ylim((np.min(X), np.max(X)))
         ax2.grid(True)
+        plt.show()
         return ax1, ax2
 
-    def import_example(self, data='2dpeaks', url=None, sep=';'):
+    def import_example(self, data='2dpeaks', url=None, sep=';', datadir=None):
         """Import example dataset from github source.
 
         Description
@@ -904,6 +914,9 @@ class findpeaks():
             url link to to dataset.
         Verbose : int (default : 3)
             Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace.
+        datadir : path-like
+            Directory to store downloaded datasets in. Defaults to data sub-directory
+            of findpeaks install location.
 
         Returns
         -------
@@ -911,7 +924,7 @@ class findpeaks():
             Dataset containing mixed features.
 
         """
-        X = _import_example(data=data, url=url, sep=sep, verbose=self.verbose)
+        X = _import_example(data=data, url=url, sep=sep, verbose=self.verbose, datadir=datadir)
         return X
 
 
@@ -935,11 +948,12 @@ def _plot_original(X, xs, labx, min_peaks, max_peaks, title=None, legend=True, a
     if legend: ax.legend(loc=0)
     ax.set_title(title)
     ax.grid(True)
+    plt.show()
     return ax
 
 
 # %% Import example dataset from github.
-def _import_example(data='2dpeaks', url=None, sep=';', verbose=3):
+def _import_example(data='2dpeaks', url=None, sep=';', verbose=3, datadir=None):
     """Import example dataset from github source.
 
     Description
@@ -954,6 +968,9 @@ def _import_example(data='2dpeaks', url=None, sep=';', verbose=3):
         url link to to dataset.
     Verbose : int (default : 3)
         Print to screen. 0: None, 1: Error, 2: Warning, 3: Info, 4: Debug, 5: Trace.
+    datadir : path-like
+        Directory to store downloaded datasets in. Defaults to data sub-directory
+        of findpeaks install location.
 
     Returns
     -------
@@ -962,11 +979,17 @@ def _import_example(data='2dpeaks', url=None, sep=';', verbose=3):
 
     """
     if url is not None:
-        data = wget.filename_from_url(url)
+        fn = os.path.basename(urlparse(url).path).strip()
+        if not fn:
+            if verbose>=3: print('[findpeaks] >Could not determine filename to download <return>.')
+            return None
+        data, _ = os.path.splitext(fn)
     elif data=='2dpeaks_image':
         url='https://erdogant.github.io/datasets/' + data + '.png'
+        fn = "2dpeaks_image.png"
     elif data=='2dpeaks':
         url='https://erdogant.github.io/datasets/' + data + '.zip'
+        fn = "2dpeaks.zip"
     elif data=='1dpeaks':
         x = [0,   13,  22,  30,  35,  38,   42,   51,   57,   67,  73,   75,  89,   126,  141,  150,  200 ]
         y = [1.5, 0.8, 1.2, 0.2, 0.4, 0.39, 0.42, 0.22, 0.23, 0.1, 0.11, 0.1, 0.14, 0.09, 0.04,  0.02, 0.01]
@@ -976,15 +999,19 @@ def _import_example(data='2dpeaks', url=None, sep=';', verbose=3):
         if verbose>=3: print('[findpeaks] >Nothing to download <return>.')
         return None
 
-    curpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
-    PATH_TO_DATA = os.path.join(curpath, wget.filename_from_url(url))
-    if not os.path.isdir(curpath):
-        os.makedirs(curpath, exist_ok=True)
+    if datadir is None:
+        datadir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'data')
+    PATH_TO_DATA = os.path.join(datadir, fn)
+    if not os.path.isdir(datadir):
+        os.makedirs(datadir, exist_ok=True)
 
     # Check file exists.
     if not os.path.isfile(PATH_TO_DATA):
         if verbose>=3: print('[findpeaks] >Downloading from github source: [%s]' %(url))
-        wget.download(url, curpath)
+        r = requests.get(url, stream=True)
+        with open(PATH_TO_DATA, "wb") as fd:
+            for chunk in r.iter_content(chunk_size=1024):
+                fd.write(chunk)
 
     # Import local dataset
     if verbose>=3: print('[findpeaks] >Import [%s]' %(PATH_TO_DATA))
